Main Menu

[ANN] ypool.net - Fast PTS pool

Started by jh00, November 12, 2013, 01:08:21 AM

Previous topic - Next topic

0 Members and 1 Guest are viewing this topic.

Ethapus

I have 3 pts and still no payout even though payout set to 2 pts. What's wrong?

liberman

Quote from: tyeken8 <br />same problem here<br />/quote]

verify your current coin mode is pts

Yeah, that was the problem.

Gumik

Just tried -m1024 instead of -m512, seems to change nothing for me collision/min wise.
XPM : AaMussGvG8963TZKswLVwY1BNG3zs22MvK
PTS : PpTe2GPfXkk1T4boaPATERzwVx5Sn5nyRr

tyeken8


liberman

jh00, what is happening to the page? Is our money all right?

NineLives

Keyhotee / BTSX:  Merah    PTS:  PskEDN4AeWc1trW4zV7DGGTQi3y5LeVhFR 

BTC Mining Hardware IN STOCK NOW:  [url="http://www.mininghardware.co.uk"]http://www.mininghardware.co.uk[/url]

Frz

Quote from: tyeken8 on November 13, 2013, 03:49:20 PM
Quote from: Frz on November 13, 2013, 03:18:43 PM
I tried switching to the sphlib library for better sha512 performance, I seem to be getting about 50% more collisions per minute on my test system

I would be happy if someone could test how it affects their performance.
https://github.com/FrzMe/jhProtominer/tree/linux-port

Great work!!
It boost my E5620 from 91 to ~96. Not very fast, don't know why..

I've merged your changeset (-b sph), add memory of 1024 ~4096MB as well.

Thank you!

I've also experimented with bigger memory sizes (https://github.com/FrzMe/jhProtominer/commit/ce443328095264700f8eb3bd3cbea4187e9e115c ) not sure of the results yet. I've moved the worker function to a new file that can be tweaked with macros to avoid code duplication in the source hope I've done that correctly :D I've moved the worker function to a new file that can be tweaked with macros to avoid code duplication in the source hope I've done that correctly :D

My test system is rather slow that's probably the reason why I get so much more performance with the new hash library (8virtual cores with 4500 mhz host cpu capped -> ~ 1/4 of a more or less modern xeon => I originally had about 30cps, now around 42)

QuoteThe last version has 76 c/m in my system, and this new one about 84c/m. BUT, this new version doesn't find any hash in several minutes I have been running it.
Maybe you are just unlucky? :( Of course there might be something wrong but it works fine for me.

QuoteHow are you compiling this?
make CFLAGS="-Ofast -march=native"
Haven't tried it on Windows.

liberman


NineLives

Keyhotee / BTSX:  Merah    PTS:  PskEDN4AeWc1trW4zV7DGGTQi3y5LeVhFR 

BTC Mining Hardware IN STOCK NOW:  [url="http://www.mininghardware.co.uk"]http://www.mininghardware.co.uk[/url]

alexr

Donations/donazioni | Sezione italiana

joesmoe

Quote from: Proto on November 13, 2013, 03:43:32 PM
Quote from: Frz on November 13, 2013, 03:18:43 PM
I tried switching to the sphlib library for better sha512 performance, I seem to be getting about 50% more collisions per minute on my test system

I would be happy if someone could test how it affects their performance.
https://github.com/FrzMe/jhProtominer/tree/linux-port

10% more collisions on a 16 core (32 threads) machine.

How are you compiling this?


liberman

Quote from: Frz on November 13, 2013, 03:18:43 PM
I tried switching to the sphlib library for better sha512 performance, I seem to be getting about 50% more collisions per minute on my test system

I would be happy if someone could test how it affects their performance.
https://github.com/FrzMe/jhProtominer/tree/linux-port

The last version has 76 c/m in my system, and this new one about 84c/m. BUT, this new version doesn't find any hash in several minutes I have been running it.

tyeken8

Quote from: Frz on November 13, 2013, 03:18:43 PM
I tried switching to the sphlib library for better sha512 performance, I seem to be getting about 50% more collisions per minute on my test system

I would be happy if someone could test how it affects their performance.
https://github.com/FrzMe/jhProtominer/tree/linux-port

Great work!!
It boost my E5620 from 91 to ~96. Not very fast, don't know why..

I've merged your changeset (-b sph), add memory of 1024 ~4096MB as well.

goldbishop


alexr

hey jh00 HUGE problem, my balance back to 0.0000000 PTS
Donations/donazioni | Sezione italiana